@@ -5,7 +5,7 @@ Created on Sun Nov  7 11:58:46 2021
 @author: kentang
 """
 
-from kintaiyi.config import *
+from config import *
 import sxtwl, re, math, itertools, datetime
 import numpy as np
 
@@ -41,6 +41,7 @@ class Taiyi:
         #陰陽遁定制
         self.gong = dict(zip(list("子丑艮寅卯辰巽巳午未坤申酉戌乾亥"), range(1,17)))
         self.gong1 = list("子丑艮寅卯辰巽巳午未坤申酉戌乾亥")
+        self.gong2 = dict(zip(list("亥子丑艮寅卯辰巽巳午未坤申酉戌乾"), [8,8,3,3,4,4,9,9,2,2,7,7,6,6,1,1]))
         self.yang_sixteen = list("申酉戌乾乾亥子丑艮寅卯辰巽巳午未坤坤")
         self.ying_sixteen = list("寅卯辰巽巽巳午未坤申酉戌乾亥子丑艮艮")
         self.yangji = list("寅丑子亥戌酉申未午巳辰卯")
@@ -61,6 +62,8 @@ class Taiyi:
         self.hegod = dict(zip(list("子寅卯辰巳午丑亥戌酉申未"),list("丑亥戌酉申未子寅卯辰巳午"))).get(self.taishui)
         #計神
         self.jigod = dict(zip(Zhi, self.findji )).get(self.taishui)
+        #八門
+        self.ed = list("開休生傷杜景死驚")
         
         
        
@@ -82,27 +85,23 @@ class Taiyi:
     
     #干支
     def gangzhi(self):
-        lunar = sxtwl.Lunar()
-        cdate = lunar.getDayBySolar(self.year, self.month, self.day)
-        yy_mm_dd = Gan[cdate.Lyear2.tg]+Zhi[cdate.Lyear2.dz],  Gan[cdate.Lmonth2.tg]+Zhi[cdate.Lmonth2.dz],  Gan[cdate.Lday2.tg]+Zhi[cdate.Lday2.dz]
-        timegz = lunar.getShiGz(cdate.Lday2.tg, self.hour)
-        new_hh = Gan[timegz.tg]+Zhi[timegz.dz]
-        return yy_mm_dd[0], yy_mm_dd[1],  yy_mm_dd[2], new_hh
+        cdate = sxtwl.fromSolar(self.year, self.month, self.day)
+        yTG = Gan[cdate.getYearGZ().tg] + Zhi[cdate.getYearGZ().dz]
+        mTG = Gan[cdate.getMonthGZ().tg] + Zhi[cdate.getMonthGZ().dz]
+        dTG  = Gan[cdate.getDayGZ().tg] + Zhi[cdate.getDayGZ().dz]
+        hTG = Gan[cdate.getHourGZ(self.hour).tg] + Zhi[cdate.getHourGZ(self.hour).dz]
+        return [yTG, mTG, dTG, hTG]
     
     def lunar_date_d(self):
-        lunar = sxtwl.Lunar()
-        day = lunar.getDayBySolar(self.year, self.month, self.day)
-        return {"月": self.ymc[day.Lmc], "日":self.rmc[day.Ldi]}
+        day = sxtwl.fromSolar(self.year, self.month, self.day)
+        return {"月": day.getLunarMonth(), "日":day.getLunarDay()}
     
     def dzdistance(self):
-        lunar = sxtwl.Lunar()
-        day = lunar.getDayBySolar(int(self.year), int(self.month), int(self.day) ).cur_dz
-        return day
+        return [twentyfourjieqir(self.year).get("冬至") - datetime.datetime.strptime(str(self.year)+"-"+str(self.month)+"-"+str(self.day), '%Y-%m-%d').date()][0].days
+   
     
     def xzdistance(self):
-        lunar = sxtwl.Lunar()
-        day = lunar.getDayBySolar(int(self.year), int(self.month), int(self.day) ).cur_xz
-        return day
+        return [twentyfourjieqir(self.year).get("夏至") - datetime.datetime.strptime(str(self.year)+"-"+str(self.month)+"-"+str(self.day), '%Y-%m-%d').date()][0].days
         
     def kook(self):
         dz = self.dzdistance()
@@ -160,6 +159,23 @@ class Taiyi:
                         ((self.taiyiyear + self.year) * 12 - 10 + self.month + self.dzdistance()+ 1) * 12 + math.ceil(self.hour / 2 ) + 1
                         ]))
     def gakook(self):
+        ty = self.ty()
+        wc = self.gong2.get(self.skyeyes)
+        sf = self.gong2.get(self.sf())
+        hg = self.gong2.get(self.home_general())
+        ag = self.gong2.get(self.away_general())
+        hvg = self.gong2.get(self.home_vgen())
+        avg = self.gong2.get(self.away_vgen())
+        sg = self.gong2.get(self.set_general())
+        svg = self.gong2.get(self.set_vgen())
+        if ty == wc:
+            gk = self.skyeyes + "掩太乙"
+        elif ty == sf:
+            gk = self.sf() + "掩太乙"
+        elif self.num.index(ty) - self.num.index(wc) == 1 or -1 or 7 or -7:
+            gk = self.skyeyes + "迫太乙"
+        elif self.num.index(ty) - self.num.index(sf) == 1 or -1 or 7 or -7:
+            gk = self.sf() + "提挾太乙"
         #掩 : 太乙 文昌 同宮 / 始擊 太乙 同宮
         #迫 : 文昌在太乙左右
         #關 : 主客四將同宮
@@ -307,7 +323,7 @@ class Taiyi:
         elif se_jc !=1 and ty_jc !=1 and se_jc1 !=1 :
             return sum(se_order[: se_order.index(ty)])
         elif se_jc !=1 and ty_jc !=1 and se_jc1 !=1 and se_num != ty:
-            return sum(se_order[: se_order.index(ty)])
+            return sum(sf_order[: sf_order.index(ty)])
         elif se_jc !=1 and ty_jc !=1 and se_jc1 !=1 and se_num == ty:
             return ty
     
@@ -358,7 +374,10 @@ class Taiyi:
                         res[list] = dict[list]
                     except TypeError:
                         pass
-        return res 
+        rres = str(res.values())[11:].replace("([","").replace("'","").replace("])","").replace(" ", "").split(",")
+        rrres = [re.findall("..", i) for i in rres]
+        r = str(res.keys())[11:].replace("([","").replace("'","").replace("])","").replace(" ", "").split(",")
+        return {r[i]:rrres[i] for i in range(0,16)}
 
     def nine_gong(self):
         dict1 = [{self.home_general():"主將"},{self.home_vgen():"主參"},{self.away_general():"客將"},
@@ -540,6 +559,24 @@ class Taiyi:
             fv = 5
         return fv
     
+    #八門
+    def eight_door(self):
+        acc = self.accHour % 120
+        if acc == 0:
+            acc = 120
+        eightdoor_zhishi = acc // 30
+        if eightdoor_zhishi % 30 != 0:
+           eightdoor_zhishi = eightdoor_zhishi + 1
+        if self.kook()[0] == "陽":
+            fdoor = [1,8,3,6]
+        elif self.kook()[0] == "陰":
+            fdoor = [9,2,7,4]
+        ty_gong = self.ty()
+        #leading = dict(zip(range(1,5), four_door)).get(eightdoor_zhishi)
+        #new_leading = self.new_list(self.num, int(leading))
+        #return dict(zip(new_leading, self.ed))
+        return self.new_list(self.num, fdoor[eightdoor_zhishi]), eightdoor_zhishi
+    
     def pan(self):
         return {
                 "干支":self.gangzhi(),
@@ -559,7 +596,8 @@ class Taiyi:
                 "九宮":self.nine_gong(), 
                 "十六宮":self.sixteen_gong(),
                 }
-        
+    
+    
     def html(self):
         text = '''<html><body><table border="0" cellpadding="1" cellspacing="1" style="width:500px">
     	<tbody>
@@ -668,10 +706,10 @@ class Taiyi:
     </table>
     
     <p>&nbsp;</p></body></html>
+
          ''' 
         return text
-	
 
 
 if __name__ == '__main__':
-    print(Taiyi(2021,11,16,10).pan())
+    print(Taiyi(2022,3,8,0).pan())
